# Pydre Overview

Pydre (pronounced *pie-dray*) is a Python software package designed to analyze the raw driving data taken from real-time driving simulation research studies. 

Pydre was originally based on the output file format from the [SimObserver](https://www.faac.com/realtime-technologies/products/simobserver-pro/) system sold by Realtime Technologies for recording data from their SimCreator simulation system. However, it can also input data from Scanner software and any similar tabular time-series data.

# Documentation

Full documentation can be found on [GitHub pages](https://osudsl.github.io/pydre/).

# Support 

If you find a bug in Pydre, please report it using the [issues](https://github.com/OSUDSL/pydre/issues) feature on GitHub. For contribution information, please view the [contributing](https://osudsl.github.io/pydre/contrib/) page in the documentation.

# Credits

Pydre was developed by The Ohio State University [Driving Simulation Lab](https://drivesim.osu.edu/).


If you use Pydre in your research, please cite [Pydre: A Python package for driving simulation data reduction](https://doi.org/10.21105/joss.07870) in JOSS.

[![DOI](https://joss.theoj.org/papers/10.21105/joss.07870/status.svg)](https://doi.org/10.21105/joss.07870)


